/****************************************************************************
  FILE: wv+vrml.h, TomaszMajor-31Jul96, wv-v0.8-8Aug96
  PURPOSE: wavelet elevation and texture compression for vrml viewer
****************************************************************************/


#ifndef _WV_VRML_H
# define _WV_VRML_H



#define wv_t void


extern "C" 
{
  
wv_t *new_wv(int size);

void delete_wv(wv_t **wv);

/****************************************************************************
  FUNCTIONS:
    enc_elev_wv() - encode elevation;
    dec_elev_wv() - decode elevation;
    enc_texr_wv() - encode texture;
    dec_texr_wv() - decode texture;
  ARGUMENTS:
    float **elev - elevation data [-11000,8848],
                   elev[size][size];
    unsigned char *texr - texture data [0,256) in headerless ppm format,
                          texr[3*(size^2)];
    int size - vertical and horizontal size of elev or texr {128,256,512};
    unsigned char *stream - buffer for compressed data,
                            stream[*stream_len];
    long *stream_len - length of stream
                       input:[256,INT_MAX], output:[0,{input *stream_len}];
    int qlty - quality of picture [8,32);
  RETURN: int - 0 if OK, !0 - otherwise (check *stream_len than);
****************************************************************************/
int enc_elev_wv(wv_t *wv,
		float **elev,
		unsigned char *stream,int stream_len); 
        	   
int dec_elev_wv(wv_t *wv,
		unsigned char *stream,int stream_len,
		float **elev); 
        	   
int enc_texr_wv(wv_t *wv,
		unsigned char *texr,
		unsigned char *stream,long *stream_len,
		int qlty); 
        	   
int dec_texr_wv(wv_t *wv,
		unsigned char *stream,long *stream_len,
		unsigned char *texr,
		int qlty); 
}



#endif /*!_WV_VRML_H*/


